@@ -18,10 +18,15 @@
 
 // -=- WinVNC Version 4.0 Service-Mode implementation
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <winvnc/VNCServerService.h>
-#include <rfb_win32/OSVersion.h>
+#include <rfb/LogWriter.h>
 #include <rfb_win32/TsSessions.h>
 #include <rfb_win32/ModuleFileName.h>
+#include <windows.h>
 #include <wtsapi32.h>
 #include <tlhelp32.h>
 
@@ -29,21 +34,27 @@ using namespace winvnc;
 using namespace rfb;
 using namespace win32;
 
-const TCHAR* winvnc::VNCServerService::Name = _T("WinVNC4");
+const TCHAR* winvnc::VNCServerService::Name = _T("TigerVNC");
+
+// SendSAS is not available until Windows 7, and missing from MinGW
+static HMODULE sasLibrary = NULL;
+typedef void WINAPI (*SendSAS_proto)(BOOL AsUser);
+static SendSAS_proto _SendSAS = NULL;
 
 VNCServerService::VNCServerService()
   : Service(Name)
-  , SendSas(_T("sas.dll"), "SendSAS")
   , stopServiceEvent(CreateEvent(0, FALSE, FALSE, 0))
   , sessionEvent(CreateEvent(0, FALSE, FALSE, "Global\\SessionEventTigerVNC"))
   , sessionEventCad(CreateEvent(0, FALSE, FALSE, "Global\\SessionEventTigerVNCCad")) {
+  if (sasLibrary == NULL) {
+    sasLibrary = LoadLibrary("sas.dll");
+    if (sasLibrary != NULL)
+      _SendSAS = (SendSAS_proto)GetProcAddress(sasLibrary, "SendSAS");
+  }
   // - Set the service-mode logging defaults
   //   These will be overridden by the Log option in the
   //   registry, if present.
-  if (osVersion.isPlatformNT)
-    logParams.setParam("*:EventLog:0,Connections:EventLog:100");
-  else
-    logParams.setParam("*:file:0,Connections:file:100");
+  logParams.setParam("*:EventLog:0,Connections:EventLog:100");
 }
 
 
@@ -97,9 +108,8 @@ HANDLE LaunchProcessWin(DWORD dwSessionId)
     if (GetSessionUserTokenWin(&hToken))
     {
         ModuleFileName filename;
-        static const char cmdLineFmt[] = "\"%s\" -noconsole -service_run";
-        TCharArray cmdLine(_tcslen(filename.buf) + sizeof(cmdLineFmt)/sizeof(cmdLineFmt[0]));
-        _stprintf(cmdLine.buf, cmdLineFmt, filename.buf);
+        TCharArray cmdLine;
+        cmdLine.format("\"%s\" -noconsole -service_run", filename.buf);
         STARTUPINFO si;
         ZeroMemory(&si, sizeof si);
         si.cb = sizeof si;
@@ -137,8 +147,8 @@ DWORD VNCServerService::serviceMain(int argc, TCHAR* argv[])
 
         //cad request
         case WAIT_OBJECT_0 + 1:
-            if (SendSas.isValid())
-                (*SendSas)(FALSE);
+            if (_SendSAS != NULL)
+                _SendSAS(FALSE);
             break; 
 
         case WAIT_TIMEOUT:
